@@ -133,11 +133,12 @@ ts_auto_smooth_es <- function(.data, .date_col, .value_col, .formula, .rsamp_obj
 
     rec_obj <- rec_obj %>%
         timetk::step_timeseries_signature({{date_col_var_expr}}) %>%
-        timetk::step_holiday_signature({{date_col_var_expr}}) %>%
+       # timetk::step_holiday_signature({{date_col_var_expr}}) %>%
         recipes::step_novel(recipes::all_nominal_predictors()) %>%
         recipes::step_mutate_at(tidyselect::vars_select_helpers$where(is.character)
                                 , fn = ~ as.factor(.)) %>%
         recipes::step_dummy(recipes::all_nominal(), one_hot = TRUE) %>%
+        recipes::step_zv(recipes::all_predictors()) %>%
         recipes::step_normalize(recipes::all_numeric_predictors(), -date_col_index.num) %>%
         recipes::step_nzv(recipes::all_predictors(), -date_col_index.num) %>%
         recipes::step_corr(recipes::all_numeric_predictors(), threshold = 0)
@@ -277,5 +278,5 @@ ts_auto_smooth_es <- function(.data, .date_col, .value_col, .formula, .rsamp_obj
     attr(output, ".parsnip_engine") <- "smooth_es"
     attr(output, ".function_family") <- "boilerplate"
 
-    return(invisible(output))
+    return(output)
 }
